model ChemicalTankReactor "A Continuously Stirred Tank Reactor"
  parameter Modelica.SIunits.VolumeFlowRate F0=100/1000/60 "Inflow";
  parameter Modelica.SIunits.Concentration c0=1000 "Concentration of inflow";
  parameter Modelica.SIunits.VolumeFlowRate F=100/1000/60 "Outflow";
  parameter Modelica.SIunits.Temp_K T0=350;
  parameter Modelica.SIunits.Length r=0.219;
  parameter Real k0=72000000000.0/60;
  parameter Real EdivR=8750;
  parameter Real U=915.6;
  parameter Real rho=1000;
  parameter Real Cp=0.239*1000;
  parameter Real dH=-50000.0;
  parameter Modelica.SIunits.Volume V=100 "Reactor Volume";
  parameter Modelica.SIunits.Concentration c_init=1000;
  parameter Modelica.SIunits.Temp_K T_init=350;
  Real c(start=c_init, fixed=true);
  Real T(start=T_init, fixed=true);
  annotation(__Wolfram(useDocumentationTemplate=false), uses(Modelica(version="3.1")), preferredView="info", Icon(coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10}), graphics={Text(visible=true, origin={0.0,21.0}, lineColor={255,0,0}, extent={{-120.0,73.0},{120.0,132.0}}, textString="%name", fontName="Arial"),Rectangle(visible=true, lineColor={111,0,0}, fillColor={255,0,0}, fillPattern=FillPattern.HorizontalCylinder, lineThickness=4, extent={{-90.0,-90.0},{90.0,90.0}}, radius=25),Text(visible=true, origin={12.0,20.8333}, fillColor={255,255,255}, fillPattern=FillPattern.Solid, extent={{-102.0,-70.8333},{78.0,29.1667}}, textString="Ex", fontName="Arial")}), Diagram(coordinateSystem(extent={{-100.0,-100.0},{100.0,100.0}}, preserveAspectRatio=true, initialScale=0.1, grid={10,10}), graphics={Ellipse(visible=true, origin={0.0,-20.0}, fillColor={192,192,192}, pattern=LinePattern.None, fillPattern=FillPattern.Solid, lineThickness=0, extent={{-70.0,-20.0},{70.0,20.0}}),Ellipse(visible=true, origin={0.0,50.0}, lineColor={192,192,192}, fillColor={192,192,192}, pattern=LinePattern.None, fillPattern=FillPattern.Solid, lineThickness=0, extent={{-70.0,-20.0},{70.0,20.0}}),Rectangle(visible=true, origin={0.0,15.0}, lineColor={128,128,128}, fillColor={192,192,192}, pattern=LinePattern.None, fillPattern=FillPattern.Solid, lineThickness=0, extent={{-70.0,-35.0},{70.0,35.0}}),Rectangle(visible=true, origin={0.0,17.5}, lineColor={75,108,20}, fillColor={202,255,106}, pattern=LinePattern.None, fillPattern=FillPattern.VerticalCylinder, lineThickness=0, extent={{-60.0,-32.5},{60.0,32.5}}),Ellipse(visible=true, origin={0.0,50.0}, lineColor={143,178,75}, fillColor={228,255,177}, pattern=LinePattern.None, fillPattern=FillPattern.VerticalCylinder, lineThickness=0, extent={{-60.0,-15.0},{60.0,15.0}}),Text(visible=true, origin={-84.5646,30.0}, fillColor={0,0,255}, fillPattern=FillPattern.Solid, lineThickness=1, extent={{-14.5646,-10.0},{14.5646,10.0}}, textString="Tc", fontName="Arial"),Ellipse(visible=true, origin={20.0,15.0}, lineColor={64,64,64}, fillColor={192,192,192}, pattern=LinePattern.None, fillPattern=FillPattern.Sphere, lineThickness=0, extent={{-20.0,-5.0},{20.0,5.0}}),Ellipse(visible=true, origin={-20.0,15.0}, lineColor={64,64,64}, fillColor={192,192,192}, pattern=LinePattern.None, fillPattern=FillPattern.Sphere, lineThickness=0, extent={{-20.0,-5.0},{20.0,5.0}}),Text(visible=true, origin={-2.6458,-54.2333}, fillPattern=FillPattern.Solid, extent={{-65.0,-10.0},{65.0,10.0}}, textString="Reaction A to B", fontName="Arial"),Text(visible=true, origin={0.0,-10.0}, fillPattern=FillPattern.Solid, lineThickness=1, extent={{-20.0,-10.0},{20.0,10.0}}, textString="c, T", fontName="Arial"),Text(visible=true, origin={-63.8253,73.6595}, fillColor={0,0,255}, fillPattern=FillPattern.Solid, extent={{-29.6461,-10.8384},{29.6461,10.8384}}, textString="Cooling jacket", fontName="Arial"),Line(visible=true, origin={0.0,30.0}, points={{0.0,20.0},{0.0,-20.0}}, color={128,128,128}, thickness=1),Ellipse(visible=true, origin={0.0,-15.0}, lineColor={75,108,20}, fillColor={202,255,106}, pattern=LinePattern.None, fillPattern=FillPattern.VerticalCylinder, lineThickness=0, extent={{-60.0,-20.0},{60.0,20.0}}),Ellipse(visible=true, origin={-0.0,50.0}, lineColor={255,255,255}, fillColor={255,255,255}, lineThickness=2, extent={{-70.0,-20.0},{70.0,20.0}}),Line(visible=true, origin={0.0,65.0}, points={{0.0,15.0},{0.0,-15.0}}, thickness=1)}), Documentation(info="<html><!--WSMINSERTIONTAGSTART CSTR -->
<head>
<style type=\"text/css\">

body {
 padding: 0px;
 margin: 0px;
}

a {
 color: #cf1d24;
}

a.target {
 padding-top: 40px;
 margin-top: -40px;
}

p {
 font-family: arial;
 font-size: 13;
 margin: 9px 40px 5px 40px;
 padding-bottom: 0px;
 color: #555555;
 max-width: 800px;
}

h1 {
 font-size: 30;
 color: #cf1d24;
 font-weight: bold;
 margin-left: 20px;
 margin-top: 32px;
 margin-bottom: 15px;
 margin-right: 20px;
 padding-top: 0px;
}

h2 {
 font-size: 20;
 color: #cf1d24;
 font-weight: bold;
 margin-left: 20px;
 margin-right: 20px;
 margin-top: 5px;
 margin-bottom: 9px;
}

h3 {
 background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
 font-size: 14px;
 font-family: helvetica;
 color: #4B4B4B;
 font-weight: bold;
 padding-left: 18px;
 margin-left: 20px;
 margin-right: 20px;
 margin-top: 12px;
 margin-bottom: 8px;
}

ul {
 font-family: arial;
 font-size: 13;
 margin: 9px 40px 5px 40px;
 padding-bottom: 0px;
 color: #555555;
 max-width: 800px;
 list-style-type: square;
}

li {
 margin-left: 0px;
 margin-top: 4px;
 margin-bottom: 2px;
 padding-left: 0px;
}

div.header {
 background: url('./DocumentationFiles/WSMLogo.png') no-repeat 0 0;
 height: 96px;
 margin-top: 35px;
 background-color: #871613;
}

.headerspan {
 font-family: arial;
 text-decoration: none;
 font-size: 12px;
 font-weight: bold;
 display: inline-block;
 height: 35px;
 color: gray;
 padding: 0px;
 margin: 0px;
 margin-left: 20px;
}

.headera {
 font-family: arial;
 text-decoration: none;
 font-size: 12px;
 font-weight: bold;
 padding: 0px;
 color: inherit;
 vertical-align: middle;
 margin: 0px;
}

.headerlinkdiv {
 background: black;
 padding: 0px;
 height: 35px;
 margin: 0px;
 position: fixed; top: 0px; left: 0px; width: 100%;
}

.contenttable {
 -webkit-box-shadow: 3px 3px 3px #DDDDDD;
 border-top: 3px solid #cf1d24;
 background: #f9f9f9;
 max-width: 500px;
 margin: 15px 15px 0px 20px;
 padding: 6px 10px 3px 10px;
}

.contenttableheader {
 color: #a4a4a4;
 font-size: 14px;
 font-family: arial;
}

.contenttabletable {
 border: 0px solid #FFFFFF;
 padding: 0px;
 padding-left: 20px;
}

.contenttable tr td {
 padding: 3px;
 min-width: 200px;
}

.contenttable tr td a {
 color: #555555;
 text-decoration: none;
 font-size: 13px;
 font-family: arial;
}

.hacek {
 color: #cf1d24;
 font-size: 25px;
 font-weight: plain;
 vertical-align: -40%;
}

.mathematicapointerwrapper {
 border: 0px solid #DDDDDD;
 margin: 15px 15px 15px 40px;
 padding: 0px;
 max-width: 500px;
}

.mathematicapointertop {
 border: 1px solid #DDDDDD;
 background-color: #F2F2F2;
 padding: 0px;
 max-width: 500px;
 height: 4px;
}

.mathematicapointerdiv {
 background: url('./DocumentationFiles/mathematicabook.png') no-repeat 5 5;
 border: 1px solid #DDDDDD;
 background-color: #FFFFFF;
 margin: 0px;
 padding: 15px 9px 9px 89px;
 max-width: 500px;
 min-height: 67px;
}

p.mathematicapointer {
 padding: 0px;
 margin: 0px;
 font-size: 12px;
}

.infoboxwrapper {
 border: 0px solid #DDDDDD;
 -webkit-box-shadow: 3px 3px 3px #DDDDDD;
 margin: 15px 15px 15px 40px;
 padding: 0px;
 max-width: 500px;
}

.infoboxtop {
 background: url('./DocumentationFiles/infotick.png') no-repeat 12 2;
 border: 1px solid #DDDDDD;
 background-color: #F2F2F2;
 padding: 0px;
 max-width: 500px;
 height: 37px;
}

div.infobox {
 border: 1px solid #DDDDDD;
 background-color: #FFFFFF;
 margin: 0px;
 padding: 15px;
 max-width: 500px;
}

p.infobox {
 padding: 0px;
 margin: 0px;
 font-size: 12px;
}

h2.legal {
 font-family: arial;
 font-size: 14;
 color: #cf1d24;
 margin: 15px 15px 15px 20px;
 font-weight: bold;
}

h3.legal {
 background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
 font-family: arial;
 font-size: 12;
 color: #808080;
 margin-left: 38px;
 padding-left: 12px;
 font-weight: bold;
}

ul.legal {
 font-size: 10px;
 font-family: arial;
 color: #555555;
 margin-left: 28px;
}

ul.legal li {
 margin-left: 0px;
 margin-top: 4px;
 margin-bottom: 2px;
 padding-left: 0px;
}

p.legallarge {
 font-size: 12px;
 margin-left: 38px;
}

p.legalsmall {
 font-size: 11px;
 margin-left: 38px;
 padding-left: 12px;
}

.legalend {
 height: 10px;
}

.variablename {
 font-family: Courier New, Courier;
}

.dialogelement {
 font-weight: bold;
}

.menuitem {
 font-weight: bold;
}

.mr {
 font-family: Courier New, Courier;
}


</style>
</head>
<body>

<div class=\"headerlinkdiv\">

<span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
padding-left: 24px;
\"
onmouseover=\"
	this.style.color = 'white';
	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
\"
onmouseout=\"
	this.style.color = 'gray';
	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
\"><a href=\"http://www.wolfram.com/system-modeler/industry-examples/\" class=\"headera\">More Examples</a></span>

<span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
padding-left: 29px;
\"
onmouseover=\"
	this.style.color = 'white';
	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
\"
onmouseout=\"
	this.style.color = 'gray';
	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
\"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>

<span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
padding-left: 20px;
\"
onmouseover=\"
	this.style.color = 'white';
	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
\"
onmouseout=\"
	this.style.color = 'gray';
	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
\"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>

<span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
padding-left: 24px;
\"
onmouseover=\"
	this.style.color = 'white';
	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
\"
onmouseout=\"
	this.style.color = 'gray';
	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
\"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
</div><div class=\"header\">&nbsp;</div>
<h1>Optimal Control for a Continuously Stirred Tank Reactor</h1><div class=\"contenttable\">
<span class=\"contenttableheader\">CONTENTS:</span><br/>
<table class=\"contenttabletable\"><tr><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Introduction').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Introduction</a></td><td><a href=\"#\" onClick=\"document.getElementById('headerTag_OptimalControl').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Optimal Control</a></td></tr><tr><td><a href=\"#\" onClick=\"document.getElementById('headerTag_InteractiveControl').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Interactive Control</a></td><td></td></tr></table></div><a id=\"headerTag_Introduction\" class=\"target\">&nbsp;</a>
<h2>Introduction</h2>
<p class=\"\">
Find an optimal control signal for a continuously stirred tank reactor (CSTR). The temperature in the tank influences a reaction rate, while the temperature in the cooling jacket acts as a control signal. The goal is to go from one concentration to another as quickly as possible, while obeying safety limitations in temperature.
</p><p class=\"\">
In order to get the full experience of this example, you need the following:
</p><ul><li>Wolfram <span style=\"font-style:italic;\">Mathematica</span>; a free trial download is available at <a href=\"http://www.wolfram.com/mathematica\">www.wolfram.com/mathematica</a></li><li>The <a href=\"ChemicalTankReactor.nb\">ChemicalTankReactor.nb</a> notebook that came in the same bundle as this model</li></ul><div class=\"mathematicapointerwrapper\">
<div class=\"mathematicapointertop\">&nbsp;</div>
<div class=\"mathematicapointerdiv\"><p class=\"mathematicapointer\">
These pages show an overview of the example. For the full example, open the accompanying notebook <a href=\"ChemicalTankReactor.nb\">ChemicalTankReactor.nb</a> in <span style=\"font-style:italic;\">Mathematica</span>.
</p></div>
</div><a id=\"headerTag_OptimalControl\" class=\"target\">&nbsp;</a>
<h2>Optimal Control</h2>
<p class=\"\">
Using <span style=\"font-style:italic;\">Mathematica</span>, find an optimal control signal for the cooling temperature to go from one concentration to another.
</p><p class=\"\">
<img src=\"DocumentationFiles/Control.png\" alt=\"\"/>
</p><a id=\"headerTag_InteractiveControl\" class=\"target\">&nbsp;</a>
<h2>Interactive Control</h2>
<p class=\"\">
<span style=\"font-style:italic;\">Mathematica</span> also makes it easy to create an interactive interface to see how the system reacts for different signals with simple drag and drop. Interact with this in the <a href=\"ChemicalTankReactor.nb\">accompanying notebook</a> (complete workflow) or in <a href=\"ChemicalTankReactor.cdf\">ChemicalTankReactor.cdf</a> (interactive result).
</p><p class=\"\">
<img src=\"DocumentationFiles/Manipulate.png\" alt=\"\"/>
</p><div class=\"mathematicapointerwrapper\">
<div class=\"mathematicapointertop\">&nbsp;</div>
<div class=\"mathematicapointerdiv\"><p class=\"mathematicapointer\">
These pages show an overview of the example. For the full example, open the accompanying notebook <a href=\"ChemicalTankReactor.nb\">ChemicalTankReactor.nb</a> in <span style=\"font-style:italic;\">Mathematica</span>.
</p></div>
</div><h2 class=\"legal\"> <a href=\"#\" onclick=\"
if(document.getElementById('61').style.display == 'none'){
document.getElementById('61').style.display = 'block';
document.getElementById('show61').style.display = 'none';
document.getElementById('hide61').style.display = 'inline';
} else {
document.getElementById('61').style.display = 'none';
document.getElementById('show61').style.display = 'inline';
document.getElementById('hide61').style.display = 'none';
};
return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"show61\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hide61\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
<span id=\"61\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
<span id=\"62\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
<span id=\"63\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
<a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
<a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
</body>
<!--WSMINSERTIONTAGEND CSTR --></html>", revisions=""));
equation 
  der(c)=F0*(c0 - c)/V - k0*c*exp(-EdivR/T);
  der(T)=F0*(T0 - T)/V - dH/(rho*Cp)*k0*c*exp(-EdivR/T) + 2*U/(r*rho*Cp)*(Tc - T);
protected 
  Modelica.Blocks.Interfaces.RealInput Tc "Cooling temperature" annotation(Placement(visible=true, transformation(origin={-80.0,0.0}, extent={{-10.0,-10.0},{10.0,10.0}}, rotation=0), iconTransformation(origin={-90.0,-20.0}, extent={{-10.0,-10.0},{10.0,10.0}}, rotation=0)));
end ChemicalTankReactor;